# idlib
[![PyPI version](https://badge.fury.io/py/idlib.svg)](https://pypi.org/project/idlib/)
[![Build Status](https://travis-ci.org/tgbugs/idlib.svg?branch=master)](https://travis-ci.org/tgbugs/idlib)
[![Coverage Status](https://coveralls.io/repos/github/tgbugs/idlib/badge.svg?branch=master)](https://coveralls.io/github/tgbugs/idlib?branch=master)

A library for working with identifiers of all kinds.
